# version_acronym is either sl or slf
# lower case please!
%define version_acronym sl

%define base_release_version 7
%define minor_release_version 0

# increment this to get the stuff after the - higher
#  helps for making the rolling one go obsolete
%define release_count 0.15

# set ROLLING true for the rolling tree
#  once set it will do the rest for you automatically
#  the only valid values are true and anything else
%define ROLLING true

# #

%define product_family Scientific Linux

# setup pretty name
%if %(echo %{version_acronym} | grep -c 'slf')
    %define release_name Tevatron
    %define variant_titlecase Fermi
    %define variant_lowercase fermi
    %define beta_directory slf7rolling
    %define beta_version 7rolling
%else
    %define release_name Nitrogen
    %define beta_directory 7rolling
    %define beta_version 7rolling
%endif

%define debug_package %{nil}
%define full_release_version %{base_release_version}.%{minor_release_version}

# if we are building for the rolling tree, define beta
%if %(echo %{ROLLING} |grep -c 'true')
    %define beta rolling
%endif


#########################################################

%define dist_release_version %{base_release_version}
%define full_release_version %{base_release_version}.%{minor_release_version}

%define dist .%{version_acronym}%{dist_release_version}

%define debug_package %{nil}

Name:           sl-release%{?variant_lowercase:-%{variant_lowercase}}
Version:        %{full_release_version}
Release:        %{release_count}%{?dist}%{?beta:.%{beta}}
Summary:        %{product_family}%{?variant_titlecase: %{variant_titlecase}} release file
Group:          System Environment/Base
License:        GPLv2
Provides:       redhat-release = %{version}-%{release}
Provides:       system-release = %{version}-%{release}
Provides:       system-release(releasever) = %{full_release_version}
Source0:        sl-release%{?variant_lowercase:-%{variant_lowercase}}-%{base_release_version}.tar.gz
Source1:        85-display-manager.preset
Source2:        90-default.preset

# SL change from TUV: for our %post script
Requires(post):	bash
Requires(post):	coreutils

# SL change from TUV: Just make SLF push SL off
%if %(echo %{version_acronym} | grep -c 'slf')
Obsoletes:	sl-release
Provides:	slf-release
Provides:	fermi-release
%endif

%description
%{product_family}%{?variant_titlecase: %{variant_titlecase}} release files

##########################

# SL change from TUV: Make yum-conf-7x
%package -n yum-conf-%{version_acronym}%{base_release_version}x
Provides:	yum-conf-%{base_release_version}x
Summary:	Utilize %{version_acronym}%{base_release_version}x repos
Group:          System Environment/Base
Requires:	sl-release%{?variant_lowercase:-%{variant_lowercase}}
BuildArch:	noarch

%if %(echo %{version_acronym} | grep -c 'slf')
Conflicts:	yum-conf-sl%{base_release_version}x
%endif

%description -n yum-conf-%{version_acronym}%{base_release_version}x
Configure the default yum repos to utilize the %{product_family}%{?variant_titlecase: %{variant_titlecase}} %{base_release_version}
latest release.

###############################################################################
%prep
%setup -q -n sl-release%{?variant_lowercase:-%{variant_lowercase}}-%{base_release_version}

%build
echo OK

%install
rm -rf %{buildroot}

# create /etc
mkdir -p %{buildroot}/etc

# create /etc/system-release and /etc/redhat-release
echo "%{product_family}%{?variant_titlecase: %{variant_titlecase}} release %{full_release_version}%{?beta: %{beta}} (%{release_name})" > %{buildroot}/etc/redhat-release
ln -s redhat-release %{buildroot}/etc/system-release


# SL change from TUV: HOME_URL
# SL change from TUV: BUG_REPORT_URL
# create /etc/os-release
cat << EOF >>%{buildroot}/etc/os-release
NAME="%{product_family}%{?variant_titlecase: %{variant_titlecase}}"
VERSION="%{full_release_version} (%{release_name})"
ID="rhel"
ID_LIKE="fedora"
VERSION_ID="%{full_release_version}"
PRETTY_NAME="%{product_family}%{?variant_titlecase: %{variant_titlecase}} %{full_release_version} (%{release_name})"
ANSI_COLOR="0;31"
CPE_NAME="cpe:/o:redhat:enterprise_linux:%{full_release_version}:%{?beta:beta}%{!?beta:GA}%{?variant_lowercase::%{variant_lowercase}}"
HOME_URL="http://www.scientificlinux.org//"
BUG_REPORT_URL="scientific-linux-devel@listserv.fnal.gov"

REDHAT_BUGZILLA_PRODUCT="%{product_family} %{base_release_version}"
REDHAT_BUGZILLA_PRODUCT_VERSION=%{full_release_version}
REDHAT_SUPPORT_PRODUCT="%{product_family}"
REDHAT_SUPPORT_PRODUCT_VERSION=%{full_release_version}
EOF
# write cpe to /etc/system/release-cpe
echo "cpe:/o:redhat:enterprise_linux:%{full_release_version}:%{?beta:beta}%{!?beta:GA}%{?variant_lowercase::%{variant_lowercase}}" | tr [A-Z] [a-z] > %{buildroot}/etc/system-release-cpe

# create /etc/issue and /etc/issue.net
echo '\S' > %{buildroot}/etc/issue
echo 'Kernel \r on an \m' >> %{buildroot}/etc/issue
cp %{buildroot}/etc/issue %{buildroot}/etc/issue.net
echo >> %{buildroot}/etc/issue

# combine GPG keys
cat RPM-GPG-KEY-redhat-release-2 RPM-GPG-KEY-redhat-auxiliary > RPM-GPG-KEY-redhat-release
rm RPM-GPG-KEY-redhat-release-2 RPM-GPG-KEY-redhat-auxiliary
cat RPM-GPG-KEY-redhat-beta-2 RPM-GPG-KEY-redhat-legacy-beta > RPM-GPG-KEY-redhat-beta
rm RPM-GPG-KEY-redhat-beta-2 RPM-GPG-KEY-redhat-legacy-beta
cat RPM-GPG-KEY-redhat-legacy-former RPM-GPG-KEY-redhat-legacy-release RPM-GPG-KEY-redhat-legacy-rhx  > RPM-GPG-KEY-redhat-legacy-other
rm RPM-GPG-KEY-redhat-legacy-former RPM-GPG-KEY-redhat-legacy-release RPM-GPG-KEY-redhat-legacy-rhx

# copy GPG keys
mkdir -p -m 755 %{buildroot}/etc/pki/rpm-gpg
for file in RPM-GPG-KEY* ; do
    install -m 644 $file %{buildroot}/etc/pki/rpm-gpg
done

# SL change from TUV: populate /etc/pki/secure-boot
mkdir -p -m 755 %{buildroot}/etc/pki/secure-boot
install -m 644 SECURE-BOOT-KEY-fnal-sl7-exp-2017-07-26 %{buildroot}/etc/pki/secure-boot

# set up the dist tag macros
install -d -m 755 %{buildroot}/etc/rpm
cat >> %{buildroot}/etc/rpm/macros.dist << EOF
# dist macros.

%%rhel %{base_release_version}
%%dist .el7
%%el%{base_release_version} 1
EOF

mkdir -p -m 755 $RPM_BUILD_ROOT/%{_datadir}/redhat-release
install -m 644 EULA $RPM_BUILD_ROOT/%{_datadir}/redhat-release
(cd $RPM_BUILD_ROOT/%{_datadir} ; ln -s redhat-release %{name})

mkdir -p -m 755 %{buildroot}/%{_docdir}/redhat-release
install -m 644 GPL %{buildroot}/%{_docdir}/redhat-release
(cd $RPM_BUILD_ROOT/%{_docdir} ; ln -s redhat-release %{name})

# copy systemd presets
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m 0644 %{SOURCE2} %{buildroot}%{_prefix}/lib/systemd/system-preset/

# SL change from TUV: for SLF disable avahi-daemon by default
%if %(echo %{version_acronym} | grep -c 'slf')
echo 'disable avahi-daemon.*' > %{buildroot}%{_prefix}/lib/systemd/system-preset/40-slf-disable-avahi.preset
%{__chmod} 644 %{buildroot}%{_prefix}/lib/systemd/system-preset/40-slf-disable-avahi.preset
%endif

# SL change from TUV: populate default repos
mkdir -p %{buildroot}%{_sysconfdir}/yum.repos.d/

for yumrepo in *.repo; do
    install -m 644  $yumrepo %{buildroot}%{_sysconfdir}/yum.repos.d/
done


# SL change from TUV: set releasever to a predictable number, 7
mkdir -p %{buildroot}%{_sysconfdir}/yum/vars
# for yum-conf-7x, your $releasever is 7
# I'd say this is the 'expected' behavior for end users
echo %{base_release_version} > %{buildroot}%{_sysconfdir}/yum/vars/releasever

# SL change from TUV: if this is for a 'beta' version, act differently
%if 0%{?beta:1}
    echo "---"
    echo "Customizing for beta version of %{product_family}%{?variant_titlecase: %{variant_titlecase}} for %{beta_directory}"
    echo "---"

    # This one goes into sl-release rather than yum-conf-7 so that our repos point automatically at rolling
    # it is a bit weird that ownership of this file changes between beta and released, but this keeps our
    # repo definitions much cleaner.... I think
    echo %{beta_version} > %{buildroot}%{_sysconfdir}/yum/vars/slreleasever

    echo "---"
%else
    # for yum-conf-7x, your $slreleasever is 7x
    # I'd say this is the 'expected' behavior for end users
    echo %{base_release_version}x > %{buildroot}%{_sysconfdir}/yum/vars/slreleasever
%endif

%clean
rm -rf %{buildroot}


##################################################################
%post -p /bin/bash
# If not defined, we've yum issues.  If no file, set to 'point release'
# for 'rolling' this file is packaged within sl-release so this never executes
if [[ ! -f %{_sysconfdir}/yum/vars/slreleasever ]]; then
    if [[ ! -d %{_sysconfdir}/yum/vars/ ]]; then
        %{__mkdir_p} %{_sysconfdir}/yum/vars/
        %{__chmod} 755 %{_sysconfdir}/yum/vars/
    fi
    echo %{full_release_version} > %{_sysconfdir}/yum/vars/slreleasever
    %{__chmod} 644 %{_sysconfdir}/yum/vars/slreleasever
fi

##################################################################
%triggerin -p /bin/bash -- initial-setup

# SL does not provide a EULA, remove the initial-setup EULA screen
if [[ -f %{python_sitelib}/initial_setup/gui/spokes/eula.py ]]; then
    rm -f %{python_sitelib}/initial_setup/gui/spokes/eula.py*
fi
if [[ -f %{python_sitelib}/initial_setup/gui/spokes/eula.glade ]]; then
    rm -f %{python_sitelib}/initial_setup/gui/spokes/eula.glade
fi

if [[ -f %{python_sitelib}/initial_setup/tui/spokes/eula.py ]]; then
    rm -f %{python_sitelib}/initial_setup/tui/spokes/eula.py*
fi

##################################################################
%triggerun -p /bin/bash -- yum-conf-%{version_acronym}%{base_release_version}x
# If we are uninstalling (not upgrading) yum-conf-7x
if [[ $2 -eq 0 ]]; then
    # If not defined, we've yum issues.  If no file, set to 'point release'
    # for 'rolling' this is packaged within sl-release so this never executes
    if [[ ! -f %{_sysconfdir}/yum/vars/slreleasever ]]; then
        echo %{full_release_version} > %{_sysconfdir}/yum/vars/slreleasever
        %{__chmod} 644 %{_sysconfdir}/yum/vars/slreleasever
    fi
fi

##################################################################
%files
%defattr(0644,root,root,0755)
/etc/redhat-release
/etc/system-release
%config(noreplace) /etc/os-release
%config /etc/system-release-cpe
%config(noreplace) /etc/issue
%config(noreplace) /etc/issue.net
%config(noreplace) %{_sysconfdir}/yum.repos.d/*
/etc/pki/rpm-gpg/
/etc/pki/secure-boot/
/etc/rpm/macros.dist
%{_docdir}/%{name}
%{_docdir}/redhat-release/*
%{_datadir}/%{name}
%{_datadir}/redhat-release/
%{_prefix}/lib/systemd/system-preset/*
# This should only include slreleasever if beta is defined
%if 0%{?beta:1}
%{_sysconfdir}/yum/vars/slreleasever
%endif

# This should only include sl/releasever if beta is not defined
%files -n yum-conf-%{version_acronym}%{base_release_version}x
%defattr(0644,root,root,0755)
%{_sysconfdir}/yum/vars/releasever
%if 0%{?beta:1}
%else
%{_sysconfdir}/yum/vars/slreleasever
%endif


%changelog
* Mon Sep 8 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.15.rolling
- added SECURE-BOOT-KEY-fnal-sl7-exp-2017-07-26

* Fri Aug 29 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.14.rolling
- typo in default dist tag

* Thu Jul 31 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.13.rolling
- updated presets for SLF
-- disable avahi-daemon.*

* Fri Jul 25 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.12.rolling
- updated macros for use with SLF

* Fri Jul 25 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.11.rolling
- now with releasever working the way I expected way back in 0.5.rolling

* Fri Jul 25 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.9.rolling
- Make absolutly sure our post script runs with defined paths

* Tue Jul 15 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.8.rolling
- Now with SL7 specific GPG key, if we find need for it

* Tue Jul 15 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.7.rolling
- Make sure /etc/yum/vars/ exists and has world read

* Mon Jul 14 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.6.rolling
- Make sure /etc/yum/vars/slreleasever has world read

* Tue Jul 08 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.5.rolling
- Now makes yum-conf-7x as part of this rpm.
-- Makes switch from rolling/released easier.
-- Still doesn't solve RC vs released....
--- Special thanks for implemented suggestions from:
----- Mátyás Selmeci
----- Andras Horvath

* Tue Jun 24 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.4.rolling
- Undo changes from 7.0-0.2.rolling

* Wed May 14 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.3.rolling
- Set repos to 7rolling

* Tue May 13 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.2.rolling
- Fixes for EULA/GPL dir location

* Mon May 12 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.1.rolling
- Fixes for firstboot

* Tue May 06 2014 Pat Riehecky <riehecky@fnal.gov> - 7.0-0.0.rolling
- Initial build for SL7

